/* ccgo: game_setup.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "game_setup.hh"
#include "part_win.hh"
#include "gmp/player.hh"
#include "settings.hh"
#include <gtkmm/box.h>
#include <gtkmm/label.h>
#include <gtkmm/button.h>
#include <gtkmm/stock.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/menu.h>

using namespace go;

PlayerSelect::PlayerSelect()
{
	Gtk::Menu * m = Gtk::manage(new Gtk::Menu);
	m->append(* Gtk::manage(new Gtk::MenuItem("Human")));
	Gtk::HBox * hb = Gtk::manage(new Gtk::HBox);
	Gtk::Label * lb = Gtk::manage(new Gtk::Label("GnuGo: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
// 	path.set_text("/usr/games/gnugo");
	hb->pack_start(path);
	m->append(* Gtk::manage(new Gtk::MenuItem(* hb)));
	set_menu(* m);
}

std::string PlayerSelect::get_path()
{
	return path.get_text();
}

void PlayerSelect::set_path(const std::string & p)
{
	path.set_text(p);
}
///////////////////////////////////////////////////////////////////////////////////////////
Player * create_player_from_select(PlayerSelect & ps)
{
	if (! ps.get_history()) return 0;
	gmp::Player * p = new gmp::Player;
	p->fork_child(ps.get_path());
	if (! (* p)) {
		delete p;
		p = 0;
	}
	return p;
}
////////////////////////////////////////////////////////////////////////////////////////////
void GameSetup::on_response(int r)
{
	switch (r) {
	case 0:
		hide();
		break;
	case 1:
		hide();
		settings.set_string("white-program-path", white.get_path());
		settings.set_string("black-program-path", black.get_path());
		new PartWin(unsigned(board_size->get_value()), komi->get_value(), create_player_from_select(white), create_player_from_select(black));
		break;
	default:
		break;
	}
}

GameSetup::GameSetup() :
	Dialog("Game setup"),
	board_size(Gtk::manage(new Gtk::Adjustment(19, 2, 25))),
	komi(Gtk::manage(new Gtk::Adjustment(5.5, -1000, 1000, 0.5)))
{
	Gtk::Label * lb = Gtk::manage(new Gtk::Label("Game setup"));
	get_vbox()->pack_start(* lb, Gtk::PACK_SHRINK);
	Gtk::HBox * hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);

	lb = Gtk::manage(new Gtk::Label("Board size: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	Gtk::SpinButton * sb = Gtk::manage(new Gtk::SpinButton(* board_size));
	sb->set_snap_to_ticks();
	hb->pack_start(* sb, Gtk::PACK_SHRINK);
	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);

	lb = Gtk::manage(new Gtk::Label("Komi: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	sb = Gtk::manage(new Gtk::SpinButton(* komi));
	sb->set_digits(1);
	sb->set_snap_to_ticks();
	hb->pack_start(* sb, Gtk::PACK_SHRINK);
	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);

	lb = Gtk::manage(new Gtk::Label("White: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(white);
	std::string n;
	n = settings.get_string("white-program-path");
	if (! n.length()) n = "/usr/games/gnugo";
	white.set_path(n);
	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);

	lb = Gtk::manage(new Gtk::Label("Black: "));
	hb->pack_start(* lb, Gtk::PACK_SHRINK);
	hb->pack_start(black);
	n = settings.get_string("black-program-path");
	if (! n.length()) n = "/usr/games/gnugo";
	black.set_path(n);

	add_button(Gtk::Stock::CANCEL, 0);
	add_button(Gtk::Stock::OK, 1);
}
